# Generated by Django 2.1 on 2019-07-11 11:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0088_auto_20190710_0953'),
        ('djconnectwise', '0087_auto_20190709_0836'),
    ]

    operations = [
    ]
