# Generated by Django 3.1.2 on 2021-01-08 16:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0141_auto_20201215_1304'),
    ]

    operations = [
        migrations.CreateModel(
            name='CommunicationType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=250)),
                ('phone_flag', models.BooleanField(default=False)),
                ('fax_flag', models.BooleanField(default=False)),
                ('email_flag', models.BooleanField(default=False)),
                ('default_flag', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='CommunicationTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_communicationtype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.communicationtype',),
        ),
    ]
