# Generated by Django 2.1.14 on 2019-12-04 08:38

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0110_project_company'),
    ]

    operations = [
        migrations.RenameField(
            model_name='scheduleentry',
            old_name='expected_date_end',
            new_name='date_end',
        ),
        migrations.RenameField(
            model_name='scheduleentry',
            old_name='expected_date_start',
            new_name='date_start',
        ),
    ]
