# Generated by Django 3.1.2 on 2020-10-15 14:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0130_activitystatustracker_activitytracker_activitytypetracker_agreementtracker_boardstatustracker_calend'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='udf',
            field=models.JSONField(blank=True, null=True),
        ),
    ]
