# Generated by Django 3.1.7 on 2021-06-23 16:27

from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0150_auto_20210610_1741'),
    ]

    operations = [
        migrations.AddField(
            model_name='item',
            name='inactive_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='subtype',
            name='inactive_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='type',
            name='inactive_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.CreateModel(
            name='TypeSubTypeItemAssociation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('board', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.connectwiseboard')),
                ('item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='associations', to='djconnectwise.item')),
                ('sub_type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='associations', to='djconnectwise.subtype')),
                ('type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='associations', to='djconnectwise.type')),
            ],
            options={
                'get_latest_by': 'modified',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TypeSubTypeItemAssociationTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_type_subtype_item_association',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.typesubtypeitemassociation',),
        ),
    ]
