# Generated by Django 3.1.1 on 2020-09-30 10:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0126_auto_20200924_1320'),
        ('djconnectwise', '0125_auto_20200923_1049'),
    ]

    operations = [
    ]
