# Generated by Django 3.1.5 on 2021-01-12 14:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0143_contactcommunication_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='contactcommunication',
            name='default_flag',
            field=models.BooleanField(blank=True, null=True),
        ),
    ]
