# Generated by Django 2.1 on 2019-07-29 13:52

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0106_auto_20190722_1524'),
    ]

    operations = [
        migrations.AddField(
            model_name='connectwiseboard',
            name='bill_time',
            field=models.CharField(blank=True, choices=[('Billable', 'Billable'), ('DoNotBill', 'Do Not Bill'), ('NoCharge', 'No Charge')], max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='member',
            name='work_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.WorkRole'),
        ),
        migrations.AddField(
            model_name='member',
            name='work_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.WorkType'),
        ),
        migrations.AddField(
            model_name='worktype',
            name='overall_default_flag',
            field=models.BooleanField(default=False),
        ),
    ]
