# Generated by Django 3.1.1 on 2020-10-03 11:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0127_merge_20200930_1011'),
    ]

    operations = [
        migrations.AlterField(
            model_name='syncjob',
            name='success',
            field=models.BooleanField(null=True),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='approved',
            field=models.BooleanField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='closed_flag',
            field=models.BooleanField(null=True),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='has_child_ticket',
            field=models.BooleanField(null=True),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='is_in_sla',
            field=models.BooleanField(null=True),
        ),
    ]
